#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-150tMLaRI1OJBErXcXtJcT
key:                  haskell-language-server-2.3.0.0-150tMLaRI1OJBErXcXtJcT
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9cb4e7a441f2ea63dc33a88ca140f5e6
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-150tMLaRI1OJBErXcXtJcT
depends:
    aeson-pretty-0.8.11-FRoaQsppo886Kr4H831C4u
    async-2.2.6-KNp1RIrM7Vj10YlQJqjVD7 base-4.18.2.1
    base16-bytestring-1.0.2.0-DtNKPfG3uwoHKAxlYu0flv
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-HXFSv1TEaSOGVlttLBUazt
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-H98LN7RYlKwJ5W6Qh2fTke filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-B1hYapL86pR4o9F5tUsmKQ
    githash-0.1.7.0-KX3fIBttawp7fXKNnAfqJc
    hie-bios-0.12.0-5BPmgjI4cuo85TDF1d4U5B
    hiedb-0.4.3.0-8aFM14CJ7nY2f0hfxENdbE
    hls-alternate-number-format-plugin-2.3.0.0-4OZEK2fcMGdHhoNAKJcfff
    hls-cabal-fmt-plugin-2.3.0.0-AKMqpAhVLZH3PDEepLAH4r
    hls-cabal-plugin-2.3.0.0-KOoNgRQpH44uHQnflrJH
    hls-call-hierarchy-plugin-2.3.0.0-FPLCIVT6bgKuVwUetWQno
    hls-change-type-signature-plugin-2.3.0.0-7IP3ko6O89w1dDbPTfrgXH
    hls-class-plugin-2.3.0.0-HbjqpxG93G8FvxLYv6ko9Y
    hls-code-range-plugin-2.3.0.0-DbiHYCDi1nTJ73HBZepcza
    hls-eval-plugin-2.3.0.0-9WVVf2PJeYVAaJN4QvhpUj
    hls-explicit-fixity-plugin-2.3.0.0-6VlLHMF4uODpYze8nBRG2
    hls-explicit-imports-plugin-2.3.0.0-HO9mtKvG7S1EShrNiSkMoL
    hls-explicit-record-fields-plugin-2.3.0.0-2N4QkFWTVwVCVOUhODye7x
    hls-fourmolu-plugin-2.3.0.0-YZBL8IBs202ABZY6zVS59
    hls-gadt-plugin-2.3.0.0-FbqRlRNHu96DDhfKponGUX
    hls-graph-2.3.0.0-HeyFkA5V638Gg24w1hlpaN
    hls-hlint-plugin-2.3.0.0-2I1hdlj67nuJJZJblTO1YO
    hls-module-name-plugin-2.3.0.0-Km4oa3awBZp3hXYOK1GFrm
    hls-ormolu-plugin-2.3.0.0-6z9KojEZv9egkDnd37rAX
    hls-overloaded-record-dot-plugin-2.3.0.0-HNMWCYEsr284GLUj3kAj2m
    hls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
    hls-pragmas-plugin-2.3.0.0-B3axiogv4Yt1kBP4B4d9sm
    hls-qualify-imported-names-plugin-2.3.0.0-HPUkA1CLylFzRNhAOsACw
    hls-refactor-plugin-2.3.0.0-EtxuNgpjn2l424w8luuejS
    hls-rename-plugin-2.3.0.0-6FLQFglBMSVHbUyMO07b40
    hls-retrie-plugin-2.3.0.0-Kp6LNJT4hTYIPlEK7BztwT
    hls-splice-plugin-2.3.0.0-7xH29wBMw1iAW1k1vgE5Zl
    hls-stylish-haskell-plugin-2.3.0.0-6VqLYFkB6ZI7eXs9itiHCz
    lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
    optparse-applicative-0.18.1.0-1Cqb5McLkWg4t2rBtbfPtX
    optparse-simple-0.1.1.4-7AyHh8Yrj8X2LPgyzd4QZ0
    prettyprinter-1.7.1-7gqni6JNC026grHQxT0UM8 process-1.6.19.0
    safe-exceptions-0.1.7.4-3EzHx1PNOrzD64ILazkZXw
    sqlite-simple-0.4.19.0-3l14XvrmGtE9Xn8Uqo07HY text-2.0.2
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

